@@ -49,12 +49,12 @@
 #include "maptile-loader.h"
 #include "maptile-module-manager.h"
 
-#define MAPTILE_REPO_CONF "~/.maptile-loader/maptile-loader.conf"
+#define MAPTILE_REPO_CONF "~/.maptile-loader/ecoach-maptile-loader.conf"
 
 /* DBUS definitions and RPC methods */
-const gchar * MAPTILE_LOADER_DBUS_SERVICE = "org.cityguide.maptileloader";
-const gchar * MAPTILE_LOADER_DBUS_OBJECT_PATH = "/org/cityguide/maptileloader";
-const gchar * MAPTILE_LOADER_DBUS_INTERFACE = "org.cityguide.maptileloader";
+const gchar * MAPTILE_LOADER_DBUS_SERVICE = "org.ecoach.maptileloader";
+const gchar * MAPTILE_LOADER_DBUS_OBJECT_PATH = "/org/ecoach/maptileloader";
+const gchar * MAPTILE_LOADER_DBUS_INTERFACE = "org.ecoach.maptileloader";
 
 const gchar * MAPTILE_LOADER_FUNCTION_GET_SUPPORTED_MAPS = "MaptileLoaderGetSupportedMaps";
 const gchar * MAPTILE_LOADER_FUNCTION_GET_MAPTILE = "MaptileLoaderGetMaptile";
@@ -144,7 +144,7 @@ int main( void )
     };
 
     result = dbus_connection_register_object_path(dbconn,
-                                                "/org/cityguide/maptileloader",
+                                                "/org/ecoach/maptileloader",
                                                 &dmap_req_vtable,
                                                 NULL);
     if (!result)
